<?php
/**
 * Timepiece functions and definitions
 *
 * @package Timepiece
 * @since Timepiece 1.0
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 *
 * @since Timepiece 1.0
 */
if ( ! isset( $content_width ) )
	$content_width = 1000; /* pixels */

/**
 * Adjust the content width on non-singular pages.
 *
 * @since Timepiece 1.0
 */
function timepiece_set_content_width() {
	global $content_width;

	if ( ! is_singular() )
		$content_width = 520;
}
add_action( 'template_redirect', 'timepiece_set_content_width' );

if ( ! function_exists( 'timepiece_setup' ) ):
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * @since Timepiece 1.0
 */
function timepiece_setup() {

	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on Timepiece, use a find and replace
	 * to change 'timepiece' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'timepiece', get_template_directory() . '/languages' );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/**
	 * Enable support for Post Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'timepiece-featured-thumbnail', 520, 400, true ); // 520 pixels wide by 400 pixels tall, hard crop mode

	/**
	 * This theme uses wp_nav_menu() in one location.
	 */
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'timepiece' ),
	) );

	/**
	 * Add support for the Aside Post Formats
	 */
	add_theme_support( 'post-formats', array( 'aside', 'gallery', 'image', 'quote', 'status', 'video' ) );
}
endif; // timepiece_setup
add_action( 'after_setup_theme', 'timepiece_setup' );

/**
* Setup the WordPress core custom background feature.
*
* Hooks into the after_setup_theme action.
*/
function timepiece_register_custom_background() {
	add_theme_support( 'custom-background', apply_filters( 'timepiece_custom_background_args', array(
		'default-color' => '0f0f0f',
		'default-image' => '',
	) ) );
}
add_action( 'after_setup_theme', 'timepiece_register_custom_background' );

/**
 * Enqueue scripts and styles
 */
function timepiece_scripts() {
	wp_enqueue_style( 'style', get_stylesheet_uri() );

	wp_enqueue_script( 'timepiece-js', get_template_directory_uri() . '/js/timepiece.js', array( 'jquery' ), '20120913', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );
}
add_action( 'wp_enqueue_scripts', 'timepiece_scripts' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/tweaks.php';

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Load Jetpack compatibility file.
 */
if ( file_exists( get_template_directory() . '/inc/jetpack.php' ) )
	require get_template_directory() . '/inc/jetpack.php';
