<?php
/**
 * Sample implementation of the Custom Header feature
 * http://codex.wordpress.org/Custom_Headers
 *
 * You can add an optional custom header image to header.php like so ...

	<?php $header_image = get_header_image();
	if ( ! empty( $header_image ) ) { ?>
		<a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home">
			<img src="<?php header_image(); ?>" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="" />
		</a>
	<?php } // if ( ! empty( $header_image ) ) ?>

 *
 * @package Timepiece
 * @since Timepiece 1.0
 */

/**
 * Setup the WordPress core custom header feature.
 *
 * @uses timepiece_header_style()
 * @uses timepiece_admin_header_style()
 * @uses timepiece_admin_header_image()
 *
 * @package Timepiece
 */
function timepiece_custom_header_setup() {
	add_theme_support( 'custom-header', apply_filters( 'timepiece_custom_header_args', array(
		'default-text-color'     => '1a1a1a',
		'width'                  => 1040,
		'height'                 => 290,
		'flex-height'            => true,
		'wp-head-callback'       => 'timepiece_header_style',
		'admin-head-callback'    => 'timepiece_admin_header_style',
		'admin-preview-callback' => 'timepiece_admin_header_image',
	) ) );
}
add_action( 'after_setup_theme', 'timepiece_custom_header_setup' );

if ( ! function_exists( 'timepiece_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 *
 * @see timepiece_custom_header_setup().
 *
 * @since Timepiece 1.0
 */
function timepiece_header_style() {

	// If no custom options for text are set, let's bail
	// get_header_textcolor() options: HEADER_TEXTCOLOR is default, hide text (returns 'blank') or any hex value
	if ( HEADER_TEXTCOLOR == get_header_textcolor() )
		return;
	// If we get this far, we have custom styles. Let's do this.
	?>
	<style type="text/css">
	<?php
		// Has the text been hidden?
		if ( 'blank' == get_header_textcolor() ) :
	?>
		.site-title,
		.site-description {
			position: absolute !important;
			clip: rect( 1px 1px 1px 1px ); /* IE6, IE7 */
			clip: rect( 1px, 1px, 1px, 1px );
		}
	<?php
		// If the user has set a custom color for the text use that
		else :
	?>
		.site-title a,
		.site-description {
			color: #<?php echo get_header_textcolor(); ?> !important;
		}
	<?php endif; ?>
	</style>
	<?php
}
endif; // timepiece_header_style

if ( ! function_exists( 'timepiece_admin_header_style' ) ) :
/**
 * Styles the header image displayed on the Appearance > Header admin panel.
 *
 * @see timepiece_custom_header_setup().
 *
 * @since Timepiece 1.0
 */
function timepiece_admin_header_style() {
?>
	<style type="text/css">
		.appearance_page_custom-header #headimg {
			border: none;
		}
		#headimg {
			background: rgb( 207, 225, 223 ); /* #cfe1df */
		}
		#headimg h1,
		#desc {
			font-weight: 300;
			padding: 0 20px;
		}
		#headimg h1 {
			font-size: 30px;
			line-height: 36px;
			margin: 0;
			padding-top: 24px;
		}
		#headimg h1 a {
			text-decoration: none;
		}
		#desc {
			color: rgba( 255, 255, 255, .6 ); /* #fff */
			font-size: 12px;
			line-height: 24px;
			font-weight: 700;
			text-transform: uppercase;
			text-shadow: 0 0 3px rgba( 0, 0, 0, .5 );
		}
		#headimg img {
			display: block;
			margin: 0 auto;
			max-width: 100%;
		}
	</style>
<?php
}
endif; // timepiece_admin_header_style

if ( ! function_exists( 'timepiece_admin_header_image' ) ) :
/**
 * Custom header image markup displayed on the Appearance > Header admin panel.
 *
 * @see timepiece_custom_header_setup().
 *
 * @since Timepiece 1.0
 */
function timepiece_admin_header_image() {
	$style        = sprintf( ' style="color:#%s;"', get_header_textcolor() );
	$header_image = get_header_image();
?>
	<div id="headimg">
		<?php if ( ! empty( $header_image ) ) : ?>
			<img src="<?php echo esc_url( $header_image ); ?>" alt="" />
		<?php endif; ?>
		<h1 class="displaying-header-text"><a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
		<div class="displaying-header-text" id="desc"<?php echo $style; ?>><?php bloginfo( 'description' ); ?></div>
	</div>
<?php
}
endif; // timepiece_admin_header_image
